#!/bin/sh
#
# HighPoint Storage Management Software Installation Script
#

HERE=`pwd`
##########
FREEBSDVER=`uname -r`
ARCH=`uname -m`
Version=1.2

case ${FREEBSDVER} in
6.*)
	if [ ${ARCH} = "amd64" ]; then
		HPTRAIDCONF=hptraidconf-5.3.amd64
		HPTSVR=hptsvr-6.0.amd64
	else
		HPTRAIDCONF=hptraidconf-5.3
		HPTSVR=hptsvr-6.0
	fi
	;;
5.[34]*)
	if [ ${ARCH} = "amd64" ]; then
		HPTRAIDCONF=hptraidconf-5.3.amd64
		HPTSVR=hptsvr-5.3.amd64
	else
		HPTRAIDCONF=hptraidconf-5.3
		HPTSVR=hptsvr-5.3
	fi
	;;
5.[012]*)
	HPTRAIDCONF=hptraidconf-5.3
	HPTSVR=hptsvr-5.2.1
	;;
4.*) 
	HPTRAIDCONF=hptraidconf-4.11
	HPTSVR=hptsvr-4.11
	;;
*)
	echo "System type is unknown!"
	HPTRAIDCONF=hptraidconf-5.3
	HPTSVR=hptsvr-5.3
	;; 
esac
#########

case $1 in
-i) 
	HPTDEL=`ps -cx | grep hptraidconf`
	if [ "x$HPTDEL" != x ] ; then
		  echo "The software is running. Please stop it first."
		  exit 1
	fi
	
	SVC_PID=`ps -cx | grep hptsvr `
	if [ "x$SVC_PID" != x ] ; then
		echo -n "The service is running. Do you want to stop it?(y/n)"
	 	read yorn
		 	case $yorn in
		 	[nN])
		 		echo "Installation abored."
		 		exit 1
		 		;;
		 	*)
		 		kill $SVC_PID >/dev/null 2>/dev/null
		 		;;
		 	esac
	fi 

	if [ ! -f $HERE/hptcli.tar.gz ] ; then
		echo "Software package not found"
		exit 1
	fi

	if [ -f /usr/bin/hptraidconf ] ; then
		while true
		do
			echo -n "The software has been installed. Do you want reinstall it?(Y/N) "
		 	read yorn
		 	case $yorn in
		 	[yY])
		 		break
		 		;;
		 	[nN])
		 		exit 1
		 		;;
		 	*)
		 		continue
		 		;;
		 	esac
		done
		
		rm -f /var/log/hpt.log
		rm -f /etc/hptuser.dat
		rm -f /etc/hptcfg
		rm -f /etc/hptmailset.dat		
		rm -f /usr/bin/hptsys.log
		rm -f  /usr/bin/hptraidconf

		rm -f  /usr/bin/hptsvr
		rm -f /usr/bin/hptsvrman.sh		
		rm -f  /usr/bin/hptcliinstall.sh 
		
		/usr/local/etc/rc.d/hptdaemon.sh stop
		rm -f  /usr/local/etc/rc.d/hptdaemon.sh
	fi
	
	if [ ! -f /etc/hptcfg ]; then
		for drv in hpt374.status hptmv.status hpt37x2.status hpt370.status; do
			sysctl $drv >/dev/null 2>/dev/null
			if [ $? -eq 0 ]; then
				echo $drv > /etc/hptcfg
				break
			fi
		done
		if [ ! -f /etc/hptcfg ]; then
			echo "Can't detect any supported driver automatically."
			echo -n "Please specify a driver: [hptmv]"
			read drv
			[ "$drv" == "" ] && drv=hptmv.status
			echo $drv > /etc/hptcfg
		fi
	fi	
	cd /tmp
	tar -xzvf $HERE/hptcli.tar.gz >/dev/null
	
	cp -f  ${HPTRAIDCONF}  /usr/bin/hptraidconf
	chmod  544	/usr/bin/hptraidconf
	
	cp -f  ${HPTSVR} /usr/bin/hptsvr
	chmod  755	/usr/bin/hptsvr
	
	cp -f hptsvrman.sh /usr/bin/	
	chmod a+x /usr/bin/hptsvrman.sh		
	
	cp -f  $HERE/hptcliinstall.sh /usr/bin/

	mkdir -p /usr/local/etc/rc.d
	cp -f hptdaemon.sh /usr/local/etc/rc.d/
	chmod 555 /usr/local/etc/rc.d/hptdaemon.sh

	rm -f  hptraid*
	rm -f  hptsvrman.sh
	rm -f  hptsvr*
	rm -f  hptdaemon.sh

	/usr/local/etc/rc.d/hptdaemon.sh start
	echo "HighPoint Storage Management Software has been installed successfully!"
	cd $HERE
	;;

-u)
	HPTDEL=`ps -cx | grep hptraidconf`
	if [ "x$HPTDEL" != x ] ; then
		  echo "The software is running. Please stop it first."
		  exit 1
	fi
	
	SVC_PID=`ps -cx | grep hptsvr `
	if [ "x$SVC_PID" != x ] ; then
		echo -n "The service is running. Do you want to stop it?(Y/N)"
	 	while true
		do
	 	read yorn
		 	case $yorn in
		 	[nN])
		 		echo "Uninstallation aborted."
		 		exit 1
		 		;;
		 	*)
		 		kill $SVC_PID >/dev/null 2>/dev/null
		 		break
		 		;;
		 	esac
		done
	fi 
	
	if [ -f /usr/bin/hptraidconf ] ; then
		while true
		do
			echo -n "Are you sure to uninstall HighPoint Storage Management Software?(Y/N)"
			read yorn
			case $yorn in
			[yY])
				rm -f /var/log/hpt.log			
				rm -f /etc/hptuser.dat
				rm -f /etc/hptcfg
				rm -f /etc/hptmailset.dat					
				rm -f /usr/bin/hptsys.log
				rm -rf /usr/bin/hptraidconf
				rm -f  /usr/bin/hptsvr
				rm -f /usr/bin/hptsvrman.sh				
				rm -f  /usr/bin/hptcliinstall.sh	 
	
				/usr/local/etc/rc.d/hptdaemon.sh stop >/dev/null 2>/dev/null
				rm -f  /usr/local/etc/rc.d/hptdaemon.sh
				
				echo "Uninstall fininshed!" 
				break
				;;
			[nN])
				break
				;;
			*)
				continue
				;;
			esac
		done 
	fi	
    ;;
*)
	echo "Usage: hptinstall.sh { -i | -u }"
	exit 1
	;; 
esac
exit 0
